        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>41</strong> miembros: 21 <br>3,4,5,7,10,11,13,15,17,19,20,24,29,30,35,39,41,43,45,46,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>16</strong> miembros: 15 <strong>control</strong><br>0,2,12,14,16,18,21,26,27,31,33,40,44,47,49';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 10 <br>1,6,9,22,23,32,34,36,37,38';}
       if(rr==6 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>28</strong> miembros: 3 <br>8,28,42';}
       if(rr==6 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>25</strong> miembros: 2 <br>25,48';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>41</strong> miembros: 21 <br>3,4,5,7,10,11,13,15,17,19,20,24,29,30,35,39,41,43,45,46,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>16</strong> miembros: 15 <strong>control</strong><br>0,2,12,14,16,18,21,26,27,31,33,40,44,47,49';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 10 <br>1,6,9,22,23,32,34,36,37,38';}
       if(rr==29 && cc==4){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>28</strong> miembros: 3 <br>8,28,42';}
       if(rr==29 && cc==5){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>25</strong> miembros: 2 <br>25,48';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>41</strong> miembros: 21 <br>3,4,5,7,10,11,13,15,17,19,20,24,29,30,35,39,41,43,45,46,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>16</strong> miembros: 15 <strong>control</strong><br>0,2,12,14,16,18,21,26,27,31,33,40,44,47,49';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 10 <br>1,6,9,22,23,32,34,36,37,38';}
       if(rr==30 && cc==4){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>28</strong> miembros: 3 <br>8,28,42';}
       if(rr==30 && cc==5){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>25</strong> miembros: 2 <br>25,48';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>41</strong> miembros: 21 <br>3,4,5,7,10,11,13,15,17,19,20,24,29,30,35,39,41,43,45,46,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>16</strong> miembros: 15 <strong>control</strong><br>0,2,12,14,16,18,21,26,27,31,33,40,44,47,49';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 10 <br>1,6,9,22,23,32,34,36,37,38';}
       if(rr==31 && cc==4){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>28</strong> miembros: 3 <br>8,28,42';}
       if(rr==31 && cc==5){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>25</strong> miembros: 2 <br>25,48';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>41</strong> miembros: 21 <br>3,4,5,7,10,11,13,15,17,19,20,24,29,30,35,39,41,43,45,46,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>16</strong> miembros: 15 <strong>control</strong><br>0,2,12,14,16,18,21,26,27,31,33,40,44,47,49';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 10 <br>1,6,9,22,23,32,34,36,37,38';}
       if(rr==32 && cc==4){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>28</strong> miembros: 3 <br>8,28,42';}
       if(rr==32 && cc==5){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>25</strong> miembros: 2 <br>25,48';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>41</strong> miembros: 21 <br>3,4,5,7,10,11,13,15,17,19,20,24,29,30,35,39,41,43,45,46,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>16</strong> miembros: 15 <strong>control</strong><br>0,2,12,14,16,18,21,26,27,31,33,40,44,47,49';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>38</strong> miembros: 10 <br>1,6,9,22,23,32,34,36,37,38';}
       if(rr==33 && cc==4){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>28</strong> miembros: 3 <br>8,28,42';}
       if(rr==33 && cc==5){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260426 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>25</strong> miembros: 2 <br>25,48';}
}
